@@ -94,10 +94,11 @@
 
 #endif
 
+#ifdef ESP_IDF_COMP_LWIP_ENABLED
 #include "lwip/lwip_napt.h"
 #include "esp_sntp.h"
-
 #include "ping/ping_sock.h"
+#endif
 
 #ifdef ESP_IDF_COMP_MBEDTLS_ENABLED
 #ifdef CONFIG_MBEDTLS_CERTIFICATE_BUNDLE
@@ -121,6 +122,10 @@
 #include "esp_http_server.h"
 #endif
 
+#ifdef ESP_IDF_ESP_WEBSOCKET_CLIENT_ENABLED
+#include "esp_websocket_client.h"
+#endif
+
 #ifdef ESP_IDF_COMP_MDNS_ENABLED
 #include "mdns.h"
 #endif
@@ -146,6 +151,7 @@
 #include "soc/rtc_periph.h"
 #endif
 
+#ifdef ESP_IDF_COMP_DRIVER_ENABLED
 #include "driver/adc.h"
 #include "driver/twai.h"
 #if !defined(CONFIG_IDF_TARGET_ESP32C3) && !defined(CONFIG_IDF_TARGET_ESP32S3)
@@ -182,6 +188,7 @@
 
 #include "driver/uart.h"
 #include "driver/uart_select.h"
+#endif
 
 #ifdef ESP_IDF_COMP_ESPCOREDUMP_ENABLED
 #include "esp_core_dump.h"
@@ -192,12 +199,12 @@
 #include "esp_serial_slave_link/essl_sdio.h"
 #endif
 
-#include "pthread.h"
-
 #ifdef ESP_IDF_COMP_PTHREAD_ENABLED
+#include "pthread.h"
 #include "esp_pthread.h"
 #endif
 
+#ifdef ESP_IDF_COMP_ULP_ENABLED
 #if (ESP_IDF_VERSION_MAJOR > 4)
 // ESP-IDF V5+
 #ifdef CONFIG_ULP_COPROC_ENABLED
@@ -233,6 +240,7 @@
 #endif
 #endif
 #endif
+#endif
 
 #ifndef CONFIG_IDF_TARGET_ESP32S2 // No BT in ESP32-S2
 
